@@ -1,6 +1,3 @@
-import numpy as np
-
-
 class Evaluator:
     """Evaluator.
 
@@ -8,13 +5,6 @@ class Evaluator:
     to match Individual implementation.
     """
 
-    def __init__(self, logger=None):
-        self.logger_ = logger
-
-    def log(self, *args, log_level=1, id=0, **kwargs):
-        if self.logger_ is not None:
-            self.logger_.log(*args, log_level=log_level, id=id, **kwargs)
-
     def eval(self, individual):
         """eval.
 
