@@ -1,17 +1,8 @@
-
-
 class Individual:
     """Individual.
 
     Base class for individuals that can be used in an Optimizer.
     """
-    def __init__(self, logger=None):
-        self.logger_ = logger
-
-    def log(self, *args, log_level=1, id=0, **kwargs):
-        if self.logger_ is not None:
-            self.logger_.log(*args, log_level=log_level, id=id, **kwargs)
-
     def copy(self):
         """copy.
         
